Module simple_rnode

Module simple_rnode 

Module with traits of rooted tree nodes

Traits

EdgeWeight
Trait bound alias for Edge Weight.
NodeTaxa
Trait bound alias for Node Taxa.
NodeWeight
Trait bound alias for Node Weight.
RootedMetaNode
A trait describing the behaviour of a Node in a n-ary tree that carries node annotations
RootedTreeNode
A trait describing the behaviour of a Node in a n-ary tree
RootedWeightedNode
A trait describing the behaviour of a Node in a n-ary tree that has numeric edge annotations
RootedZetaNode
A trait describing the behaviour of a Node in a n-ary tree with numeric node annotations