Module with traits of rooted tree nodes
Traits
- Edge
Weight - Trait bound alias for Edge Weight.
- Node
Taxa - Trait bound alias for Node Taxa.
- Node
Weight - Trait bound alias for Node Weight.
- Rooted
Meta Node - A trait describing the behaviour of a Node in a n-ary tree that carries node annotations
- Rooted
Tree Node - A trait describing the behaviour of a Node in a n-ary tree
- Rooted
Weighted Node - A trait describing the behaviour of a Node in a n-ary tree that has numeric edge annotations
- Rooted
Zeta Node - A trait describing the behaviour of a Node in a n-ary tree with numeric node annotations